@@ -16,7 +16,7 @@ def get_ft(input_row):
 
 def get_ft_level(input_row):
     if input_row.X_q is None:
-        input_row.X_q = utils.get_X_q(input_row)
+        input_row.X_q = utils.get_X_q(input_row.time_var)
     return utils.get_fft_level(input_row)
 
 
